pub struct DscdEvent {
pub id: u64,
pub time_index: u64,
pub module_id: u32,
pub residual_state: String,
pub trust: f64,
pub echo_slope: f64,
pub entropy_density: f64,
pub structural_level: f64,
}Expand description
DSCD event node exported for causal graph and scaling analyses.
EVENT TYPE NOTE:
This is the canonical event struct written to graph_events.csv. It
carries event/time indices, trust, and ADD-derived structure.
Fields
id: u64time_index: u64module_id: u32residual_state: Stringtrust: f64echo_slope: f64entropy_density: f64structural_level: f64Trait Implementations